@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgConn.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgConn.cpp 7215 2008-04-04 12:28:00Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -201,7 +201,7 @@ pgConn::pgConn(const wxString& server, const wxString& database, const wxString&
 			wxString db = database;
 			db.Replace(wxT("\\"), wxT("\\\\"));
 			db.Replace(wxT("'"), wxT("''"));
-            sql += wxT("datname='") + database + wxT("'");
+            sql += wxT("datname=") + qtString(database);
 		}
 		
 
@@ -480,11 +480,13 @@ void pgConn::RegisterNoticeProcessor(PQnoticeProcessor proc, void *arg)
 
 void pgConn::Notice(const char *msg)
 {
-    wxString str(msg, *conv);
-    wxLogNotice(wxT("%s"), str.c_str());
-
     if (noticeArg && noticeProc)
         (*noticeProc)(noticeArg, msg);
+    else
+    {
+        wxString str(msg, *conv);
+        wxLogNotice(wxT("%s"), str.Trim().c_str());
+    }
 }
 
 
@@ -530,8 +532,7 @@ bool pgConn::ExecuteVoid(const wxString& sql, bool reportError)
     if (lastResultStatus != PGRES_TUPLES_OK &&
         lastResultStatus != PGRES_COMMAND_OK)
     {
-        if (reportError)
-            LogError();
+        LogError(!reportError);
         return false;
     }
 
@@ -640,22 +641,19 @@ wxString pgConn::GetLastError() const
 
 
 
-void pgConn::LogError()
+void pgConn::LogError(const bool quiet)
 {
     if (conn)
     {
-        wxLogError(wxT("%s"), GetLastError().c_str());
-
-        IsAlive();
-#if 0
-        ConnStatusType status = PQstatus(conn);
-        if (status == CONNECTION_BAD)
+        if (quiet)
         {
-            PQfinish(conn);
-            conn=0;
-            connStatus = PGCONN_BROKEN;
+            wxLogQuietError(wxT("%s"), GetLastError().c_str());
+        }
+        else
+        {
+            wxLogError(wxT("%s"), GetLastError().c_str());
+            IsAlive();
         }
-#endif
     }
 }
 
@@ -668,7 +666,7 @@ bool pgConn::IsAlive()
         lastResultError.severity = wxString(wxT("FATAL"));
         lastResultError.msg_primary = wxString(PQerrorMessage(conn), *conv);
         lastResultError.formatted_msg = lastResultError.severity + wxT(": ") + lastResultError.msg_primary;
-        wxLogError(lastResultError.msg_primary);
+        wxLogError(wxT("%s"), lastResultError.msg_primary.c_str());
         return false;
     }
 
@@ -776,3 +774,16 @@ void pgConn::SetLastResultError(PGresult *res)
     }
     lastResultError.formatted_msg = errMsg;
 }
+
+// String quoting - only for use during the connection phase!!
+wxString pgConn::qtString(const wxString& value)
+{
+    wxString result = value;	
+
+    result.Replace(wxT("\\"), wxT("\\\\"));
+    result.Replace(wxT("'"), wxT("\\'"));
+    result.Append(wxT("'"));
+    result.Prepend(wxT("'"));
+	
+    return result;
+}
