@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSet.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgSet.cpp 7046 2008-02-04 13:50:00Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -197,7 +197,7 @@ int pgSet::ColNumber(const wxString &colname) const
         col = PQfnumber(res, colname.mb_str(conv));
 
     if (col < 0)
-        wxLogError(__("Column not found in pgSet: ") + colname);
+        wxLogError(__("Column not found in pgSet: %s"), colname.c_str());
     return col;
 }
 
