@@ -192,7 +192,7 @@ void dbgPgConn::Init( const wxString &server, const wxString &database, const wx
     connectParams.Trim( false );
 
     m_frame->getStatusBar()->SetStatusText( wxString(_( "Connecting to " )) + msg, 1 );
-    m_pgConn = PQconnectdb( connectParams.ToAscii());
+    m_pgConn = PQconnectdb( connectParams.mb_str(wxConvUTF8));
 
     if( PQstatus( m_pgConn ) == CONNECTION_OK )
     {
@@ -280,14 +280,14 @@ PGconn * dbgPgConn::getConnection()
 
 void dbgPgConn::startCommand( const wxString &command, wxEvtHandler * caller, wxEventType eventType, dbgPgParams *params )
 {
-    wxLogSql(command);
+    wxLogSql(wxT("%s"), command.c_str());
 
     m_workerThread->startCommand(command, caller, eventType, params);
 }
 
 PGresult * dbgPgConn::waitForCommand( const wxString &command )
 {
-    wxLogSql(command);
+    wxLogSql(wxT("%s"), command.c_str());
 
     PGresult * result = PQexec( m_pgConn, command.mb_str( wxConvUTF8 ));
 
@@ -413,7 +413,7 @@ DebuggerApiVersions dbgPgConn::DebuggerApiVersion()
     }
     else
     {
-        wxLogError(wxString(PQerrorMessage(m_pgConn), wxConvUTF8));
+        wxLogError(wxT("%s"), wxString(PQerrorMessage(m_pgConn), wxConvUTF8).c_str());
         return DEBUGGER_UNKNOWN_API;
     }
 
@@ -428,7 +428,7 @@ DebuggerApiVersions dbgPgConn::DebuggerApiVersion()
     }
     else
     {
-        wxLogError(wxString(PQerrorMessage(m_pgConn), wxConvUTF8));
+        wxLogError(wxT("%s"), wxString(PQerrorMessage(m_pgConn), wxConvUTF8).c_str());
         return DEBUGGER_UNKNOWN_API;
     }
 
