@@ -2,7 +2,7 @@
 //
 // pgAdmin III - PostgreSQL Tools
 // RCS-ID:      $Id: dbgTargetInfo.cpp 6202 2007-04-18 11:22:49Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dbgTargetInfo.cpp - debugger 
@@ -208,10 +208,14 @@ wsArgInfo::wsArgInfo( const wxString &argName, const wxString &argType, const wx
 
 const wxString wsArgInfo::quoteValue()
 {
-    if( m_value.CmpNoCase( wxT( "NULL" )) == 0 )
-    	return( m_value );
-    else if( m_value[0] == '\'' )
-    	return( m_value );
+    if (m_value == wxT(""))
+    	return (wxT("NULL"));
+    else if (m_value == wxT("''"))
+        return (wxT("''"));
+    else if (m_value == wxT("\\'\\'"))
+        return (wxT("'\\'\\''"));
+    else if (m_value[0] == '\'' )
+    	return(m_value);
     else
-    	return( wxString( wxT( "'" ) + m_value + wxT( "'" )));
+    	return(wxString(wxT("'") + m_value + wxT("'")));
 }
