@@ -74,7 +74,8 @@ dlgDirectDbg::dlgDirectDbg( frmDebugger *parent, wxWindowID id, const dbgConnPro
     m_targetInfo(NULL),
     m_conn(NULL),
     m_codeWindow(NULL),
-    m_parent (parent)
+    m_parent (parent),
+    m_cancelled (false)
 {
     wxWindowBase::SetFont(settings->GetSystemFont());
     LoadResource(m_parent, wxT("dlgDirectDbg"));
@@ -206,7 +207,7 @@ bool dlgDirectDbg::loadTargetInfo( const wxString &target, const dbgConnProp & c
         }
         catch( const std::runtime_error & error )
         {
-            wxLogError(wxString(error.what(), wxConvUTF8));
+            wxLogError(wxT("%s"), wxString(error.what(), wxConvUTF8).c_str());
             m_conn->Close();
             return false;
         }
@@ -377,6 +378,7 @@ void dlgDirectDbg::OnCancel( wxCommandEvent & event )
 {
     // This will raise close event which is handled by 
     // dlgDirectDbg::OnClose().
+    m_cancelled = true;
     Close();
 }
 
