@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgColumn.cpp 7003 2008-01-18 15:38:49Z dpage $
+// RCS-ID:      $Id: dlgColumn.cpp 7160 2008-03-11 09:07:07Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -146,6 +146,9 @@ int dlgColumn::Go(bool modal)
             cbClusterSet->Disable();
             cbClusterSet = 0;
         }
+
+        txtAttstattarget->Disable();
+        txtComment->Disable();
     }
     return dlgTypeProperty::Go(modal);
 }
@@ -178,7 +181,7 @@ wxString dlgColumn::GetSql()
 
             if (connection->BackendMinimumVersion(7, 5))
             {
-                if (cbDatatype->GetValue() != column->GetVarTypename() || 
+                if (cbDatatype->GetValue() != column->GetRawTypename() || 
                     (isVarLen && txtLength->IsEnabled() && StrToLong(len) != column->GetLength()) ||
                     (isVarPrec && txtPrecision->IsEnabled() && StrToLong(prec) != column->GetPrecision()))
                 {
@@ -251,19 +254,15 @@ wxString dlgColumn::GetSql()
         {
             sql = wxT("ALTER TABLE ") + table->GetQuotedFullIdentifier()
                 + wxT("\n   ADD COLUMN ") + qtIdent(name)
-                + wxT(" ") + GetQuotedTypename(cbDatatype->GetGuessedSelection())
-                + wxT(";\n");
+                + wxT(" ") + GetQuotedTypename(cbDatatype->GetGuessedSelection());
 
             if (chkNotNull->GetValue())
-                sql += wxT("ALTER TABLE ") + table->GetQuotedFullIdentifier()
-                    + wxT("\n   ALTER COLUMN ") + qtIdent(name)
-                    + wxT(" SET NOT NULL;\n");
+                sql += wxT(" NOT NULL");
         
             if (!isSerial && !txtDefault->GetValue().IsEmpty())
-                sql += wxT("ALTER TABLE ") + table->GetQuotedFullIdentifier()
-                    + wxT("\n   ALTER COLUMN ") + qtIdent(name)
-                    + wxT(" SET DEFAULT ") + txtDefault->GetValue() 
-                    + wxT(";\n");
+                sql += wxT(" DEFAULT ") + txtDefault->GetValue(); 
+            
+            sql += wxT(";\n");
 
             if (!txtAttstattarget->GetValue().IsEmpty())
                 sql += wxT("ALTER TABLE ") + table->GetQuotedFullIdentifier()
@@ -272,7 +271,6 @@ wxString dlgColumn::GetSql()
                     + wxT(";\n");
         }
 
-
         AppendComment(sql, wxT("COLUMN ") + table->GetQuotedFullIdentifier() 
                 + wxT(".") + qtIdent(name), column);
     }
@@ -378,3 +376,6 @@ void dlgColumn::CheckChange()
 
 
 
+
+
+
