@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgConnect.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgConnect.cpp 7199 2008-03-26 14:18:20Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -62,7 +62,7 @@ dlgConnect::~dlgConnect()
 
 wxString dlgConnect::GetHelpPage() const
 {
-    return wxT("pg/server-connect");
+    return wxT("connect");
 }
 
 
