@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgDatabase.cpp 7014 2008-01-23 14:36:26Z dpage $
+// RCS-ID:      $Id: dlgDatabase.cpp 7068 2008-02-08 15:24:17Z guillaume $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -246,9 +246,9 @@ void dlgDatabase::OnChangeRestr(wxCommandEvent &ev)
         schemaRestrictionOk = true;
     else
     {
-        wxString sql=wxT("EXPLAIN SELECT 1 FROM pg_namespace nsp\n")
+        wxString sql=wxT("SELECT 1 FROM pg_namespace nsp\n")
                 wxT("  JOIN pg_description des ON des.objoid=nsp.oid\n")
-                wxT(" WHERE (") + txtSchemaRestr->GetValue() + wxT(")");
+                wxT(" WHERE nspname NOT IN (") + txtSchemaRestr->GetValue() + wxT(")");
 
         wxLogNull nix;
         wxString result=connection->ExecuteScalar(sql);
