@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgEditGridOptions.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgEditGridOptions.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -325,7 +325,7 @@ bool dlgEditGridOptions::Validate()
         long errPos=0;
         errMsg.Mid(chp+atChar.Length()).ToLong(&errPos);
         errPos -= queryOffset;  // do not count EXPLAIN or similar
-        wxLogError(wxString::Format(_("ERROR: Syntax error at character %d!"), errPos));
+        wxLogError(wxT("%s"), _("ERROR: Syntax error at character %d!"), errPos);
 
         int line=0, maxLine = filter->GetLineCount();
         while (line < maxLine && filter->GetLineEndPosition(line) < errPos + selStart+1)
@@ -335,10 +335,8 @@ bool dlgEditGridOptions::Validate()
             filter->MarkerAdd(line, 0);
             filter->EnsureVisible(line);
         }
-    } else {
-		errMsg.Replace(wxT("%"), wxT("%%")); 
-        wxLogError(errMsg.BeforeFirst('\n'));
-    }
+    } else
+        wxLogError(wxT("%s"), errMsg.BeforeFirst('\n').c_str());
 
     // Cleanup
     PQclear(qryRes);
