@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgFunction.cpp 7010 2008-01-23 09:55:56Z dpage $
+// RCS-ID:      $Id: dlgFunction.cpp 7329 2008-05-30 12:49:25Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -182,7 +182,6 @@ int dlgFunction::Go(bool modal)
         if (function)
             txtName->Disable();
         cbOwner->Disable();
-        txtComment->Disable();
         cbLanguage->Disable();
         chkStrict->Disable();
         chkSecureDefiner->Disable();
@@ -865,10 +864,14 @@ wxString dlgFunction::GetSql()
         sql += GetGrant(wxT("X"), wxT("FUNCTION ") + name);
     }
 
-    AppendComment(sql, wxT("FUNCTION ") + name, function);
+	if (isProcedure)
+        AppendComment(sql, wxT("PROCEDURE ") + GetName(), function);
+	else
+        AppendComment(sql, wxT("FUNCTION ") + name, function);
 
     return sql;
 }
 
 
 
+
