@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgIndex.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgIndex.cpp 7232 2008-04-20 17:38:49Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -164,6 +164,10 @@ void dlgIndexBase::OnSelectComboCol(wxCommandEvent &ev)
 
 void dlgIndexBase::OnSelectCol()
 {
+	// Can't change the columns on an existing index.
+	if (index)
+		return;
+
     if (lstColumns->GetSelection() != wxNOT_FOUND)
         btnRemoveCol->Enable(true);
     else
@@ -374,3 +378,4 @@ pgObject *dlgIndex::CreateObject(pgCollection *collection)
 }
 
 
+
