@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgLanguage.cpp 6082 2007-03-16 12:58:18Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgLanguage.cpp 6997 2008-01-14 11:06:45Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgLanguage.cpp - PostgreSQL Language Property
@@ -202,7 +202,7 @@ wxString dlgLanguage::GetSql()
         }
     }
 
-    sql += GetGrant(wxT("X"), wxT("LANGUAGE ") + qtIdent(name));
+    sql += GetGrant(wxT("U"), wxT("LANGUAGE ") + qtIdent(name));
     AppendComment(sql, wxT("LANGUAGE ") + qtIdent(name), 0, language);
 
     return sql;
