@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgPackage.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgPackage.cpp 7324 2008-05-29 15:58:38Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -60,7 +60,9 @@ pgObject *dlgPackage::GetObject()
 
 int dlgPackage::Go(bool modal)
 {
-    txtComment->Disable();
+	if (!connection->EdbMinimumVersion(8, 2))
+		txtComment->Disable();
+
     cbOwner->Disable();
 
     AddGroups();
@@ -90,10 +92,10 @@ pgObject *dlgPackage::CreateObject(pgCollection *collection)
     
     if (collection->GetConnection()->EdbMinimumVersion(8, 2))
         obj=packageFactory.CreateObjects(collection, 0,
-            wxT("   AND nspname = '") + GetName() + wxT("'"));
+            wxT("   AND nspname = ") + qtDbString(GetName()));
     else
         obj=packageFactory.CreateObjects(collection, 0,
-            wxT("   AND pkgname = '") + GetName() + wxT("'"));
+            wxT("   AND pkgname = ") + qtDbString(GetName()));
 
     return obj;
 }
@@ -105,13 +107,15 @@ void dlgPackage::CheckChange()
 
     CheckValid(enable, !txtName->GetValue().IsEmpty(), _("Please specify name."));
     CheckValid(enable, !txtHeader->GetText().IsEmpty(), _("Please specify package header."));
-    CheckValid(enable, !txtBody->GetText().IsEmpty(), _("Please specify package body."));
 
     if (package)
     {
        if (!(txtBody->GetText() != package->GetBodyInner() ||
            txtHeader->GetText() != package->GetHeaderInner())) 
            enable = false;
+
+	   if (txtComment->GetValue() != package->GetComment())
+		   enable = true;
     }
 
     EnableOK(enable);
@@ -141,15 +145,25 @@ wxString dlgPackage::GetSql()
         sql += wxT("\nEND ") + qtIdent(txtName->GetValue()) + wxT(";\n\n");
     }
 
-    if (!package || (package && txtBody->GetText() != package->GetBodyInner())
-                 || (package && txtHeader->GetText() != package->GetHeaderInner()))
-    {
-        sql += wxT("CREATE OR REPLACE PACKAGE BODY ") + qtName + wxT("\nAS\n");
-        sql += txtBody->GetText();
-        sql += wxT("\nEND ") + qtIdent(txtName->GetValue()) + wxT(";\n\n");
-    }
+	if (!package || (package && txtBody->GetText() != package->GetBodyInner())
+				 || (package && txtHeader->GetText() != package->GetHeaderInner()))
+	{
+		if (!txtBody->GetText().IsEmpty())
+	    {
+			sql += wxT("CREATE OR REPLACE PACKAGE BODY ") + qtName + wxT("\nAS\n");
+			sql += txtBody->GetText();
+			sql += wxT("\nEND ") + qtIdent(txtName->GetValue()) + wxT(";\n\n");
+		}
+		else
+		{
+			if (package)
+				sql = wxT("DROP PACKAGE BODY ") + qtName + wxT(";\n\n");
+		}
+	}
 
     sql += GetGrant(wxT("X"), wxT("PACKAGE ") + qtName);
 
+	AppendComment(sql, wxT("PACKAGE"), schema, package);
+
     return sql;
 }
