@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgRole.cpp 6666 2007-09-25 15:25:12Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgRole.cpp 7002 2008-01-18 13:46:12Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgRole.cpp - PostgreSQL Role Property
@@ -281,14 +281,7 @@ void dlgRole::OnChangeSuperuser(wxCommandEvent &ev)
 
 void dlgRole::OnChangePasswd(wxCommandEvent &ev)
 {
-	wxString passwd=txtPasswd->GetValue();
-	wxString repasswd=txtRePasswd->GetValue();
-	if ((!repasswd.IsEmpty())||(!repasswd.IsEmpty()))
-	{
-           bool enable=true;
-           CheckValid(enable, !passwd.compare(repasswd), _("The passwords entered do not match!"));
-           EnableOK(enable);
-	}
+	CheckChange();
 }
 
 void dlgRole::CheckChange()
@@ -301,6 +294,15 @@ void dlgRole::CheckChange()
     if (!readOnly)
         chkUpdateCat->Enable(chkSuperuser->GetValue());
 
+	// Check the passwords match
+	if (txtPasswd->GetValue() != txtRePasswd->GetValue())
+	{
+           bool enable=true;
+           CheckValid(enable, false, _("The passwords entered do not match!"));
+           EnableOK(enable);
+		   return;
+	}
+
     if (!role)
     {
         wxString name=GetName();
@@ -618,19 +620,32 @@ wxString dlgRole::GetSql()
             sql += wxT("\n   VALID UNTIL 'infinity'");
         
         int cnt = lbRolesIn->GetCount();
-        int pos;
+		wxString grants;
 
         if (cnt)
         {
-            sql += wxT("\n   IN ROLE ");
-            for (pos=0 ; pos < cnt ; pos++)
+			wxString roleName;
+
+            for (int pos=0 ; pos < cnt ; pos++)
             {
-                if (pos)
-                    sql += wxT(", ");
-                sql += qtIdent(lbRolesIn->GetString(pos));
+                bool admin = false;    
+				roleName = lbRolesIn->GetString(pos);
+				if (roleName.Right(PGROLE_ADMINOPTION_LEN) == PGROLE_ADMINOPTION)
+				{
+					roleName=roleName.Left(roleName.Length()-PGROLE_ADMINOPTION_LEN);
+					admin = true;
+
+				}
+				grants += wxT("GRANT ") + qtIdent(roleName)
+					   +  wxT(" TO ") + qtIdent(name);
+
+				if (admin)
+			        grants += wxT(" WITH ADMIN OPTION;\n");
+				else
+					grants += wxT(";\n");
             }
         }
-        sql += wxT(";\n");
+        sql += wxT(";\n") + grants;
 
         if (superuser && !chkUpdateCat->GetValue())
             sql += wxT("UPDATE pg_authid SET rolcatupdate=false WHERE rolname=") + qtDbString(name) + wxT(";\n");
