@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgSelectConnection.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgSelectConnection.cpp 7046 2008-02-04 13:50:00Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -97,7 +97,7 @@ void dlgSelectConnection::OnChangeServer(wxCommandEvent& ev)
             remoteServer->Connect(mainForm, remoteServer->GetStorePwd());
             if (!remoteServer->GetConnected())
             {
-                wxLogError(remoteServer->GetLastError());
+                wxLogError(wxT("%s"), remoteServer->GetLastError().c_str());
                 return;
             }
         }
