@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgSynonym.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgSynonym.cpp 7186 2008-03-22 10:43:26Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -96,7 +96,7 @@ int dlgSynonym::Go(bool modal)
 pgObject *dlgSynonym::CreateObject(pgCollection *collection)
 {
     pgObject *obj=synonymFactory.CreateObjects(collection, 0,
-         wxT(" WHERE synname = '") + GetName() + wxT("'"));
+         wxT(" WHERE synname = ") + qtDbString(GetName()));
 
     return obj;
 }
@@ -175,7 +175,7 @@ void dlgSynonym::ProcessSchemaChange()
 
     wxString sql = wxT("SELECT relname FROM pg_class c, pg_namespace n\n")
         wxT("  WHERE c.relnamespace = n.oid AND\n")
-        wxT("        n.nspname = '") + cbTargetSchema->GetValue() + wxT("' AND\n")
+        wxT("        n.nspname = ") + qtDbString(cbTargetSchema->GetValue()) + wxT(" AND\n")
         wxT("        c.relkind = '") + restriction + wxT("' ORDER BY relname;");
 
     pgSet *objects = connection->ExecuteSet(sql);
