@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgTrigger.cpp 6603 2007-09-03 10:58:12Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: dlgTrigger.cpp 7012 2008-01-23 14:04:46Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // dlgTrigger.cpp - PostgreSQL Trigger Property
@@ -123,8 +123,8 @@ int dlgTrigger::Go(bool modal)
 
         pgSet *set=connection->ExecuteSet(
             wxT("SELECT quote_ident(nspname) || '.' || quote_ident(proname)\n")
-            wxT("  FROM pg_proc, pg_namespace\n")
-            wxT(" WHERE pg_proc.pronamespace = pg_namespace.oid AND prorettype=") + NumToStr(PGOID_TYPE_TRIGGER) + sysRestr);
+            wxT("  FROM pg_proc p, pg_namespace n, pg_language l\n")
+            wxT(" WHERE p.pronamespace = n.oid AND p.prolang = l.oid AND l.lanname != 'edbspl' AND prorettype=") + NumToStr(PGOID_TYPE_TRIGGER) + sysRestr);
         if (set)
         {
             while (!set->Eof())
@@ -210,6 +210,9 @@ wxString dlgTrigger::GetSql()
         else
         {
             sql += wxT("\n") + txtBody->GetText();
+            if (!sql.Trim().EndsWith(wxT(";")))
+                sql = sql.Trim() + wxT(";");
+            sql += wxT("\n");
         }
     }
     AppendComment(sql, wxT("TRIGGER ") + qtIdent(GetName()) 
@@ -286,3 +289,4 @@ bool dlgTrigger::IsUpToDate()
 		return true;
 }
 
+
