@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgView.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: dlgView.cpp 7221 2008-04-08 08:46:15Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -71,6 +71,14 @@ int dlgView::Go(bool modal)
         // create mode
     }
 
+    // Find, and disable the RULE ACL option if we're 8.2
+    if (connection->BackendMinimumVersion(8, 2))
+    {
+        // Disable the checkbox
+        if (!DisablePrivilege(wxT("RULE")))
+            wxLogError(_("Failed to disable the RULE privilege checkbox!"));
+    }
+
     return dlgSecurityProperty::Go(modal);
 }
 
