@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmBackup.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmBackup.cpp 7243 2008-04-29 09:06:34Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -112,7 +112,7 @@ wxString frmBackup::GetHelpPage() const
 
 void frmBackup::OnSelectFilename(wxCommandEvent &ev)
 {
-    wxString title, prompt;
+    wxString title, prompt, FilenameOnly;
 
     if (rbxFormat->GetSelection() == 2) // plain
     {
@@ -125,8 +125,8 @@ void frmBackup::OnSelectFilename(wxCommandEvent &ev)
         prompt = _("Backup files (*.backup)|*.backup|All files (*.*)|*.*");
     }
 
-    
-    wxFileDialog file(this, title, ::wxPathOnly(txtFilename->GetValue()), txtFilename->GetValue(), prompt, wxFD_SAVE);
+    wxFileName::SplitPath(txtFilename->GetValue(), NULL, NULL, &FilenameOnly, NULL);
+    wxFileDialog file(this, title, ::wxPathOnly(txtFilename->GetValue()), FilenameOnly, prompt, wxFD_SAVE);
 
     if (file.ShowModal() == wxID_OK)
     {
@@ -192,9 +192,10 @@ wxString frmBackup::getCmdPart1()
     else
         cmd=pgBackupExecutable;
 
-    cmd +=  wxT(" -i")
-            wxT(" -h ") + server->GetName()
-         +  wxT(" -p ") + NumToStr((long)server->GetPort())
+    if (!server->GetName().IsEmpty())
+        cmd += wxT(" -h ") + server->GetName();
+
+    cmd +=  wxT(" -p ") + NumToStr((long)server->GetPort())
          +  wxT(" -U ") + server->GetUsername();
     return cmd;
 }
@@ -295,7 +296,7 @@ wxString frmBackup::getCmdPart2()
 		}
     }
 
-    cmd.Append(wxT(" ") + object->GetDatabase()->GetQuotedIdentifier());
+    cmd.Append(wxT(" ") + commandLineCleanOption(object->GetDatabase()->GetQuotedIdentifier()));
 
     return cmd;
 }
@@ -353,3 +354,4 @@ bool backupFactory::CheckEnable(pgObject *obj)
 
 }
 
+
