@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmBackupServer.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmBackupServer.cpp 7243 2008-04-29 09:06:34Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -86,13 +86,14 @@ wxString frmBackupServer::GetHelpPage() const
 
 void frmBackupServer::OnSelectFilename(wxCommandEvent &ev)
 {
-    wxString title, prompt;
+    wxString title, prompt, FilenameOnly;
 
     title  = _("Select output file");
     prompt = _("Query files (*.sql)|*.sql|All files (*.*)|*.*");
     
-    wxFileDialog file(this, title, ::wxPathOnly(txtFilename->GetValue()), txtFilename->GetValue(), prompt, wxFD_SAVE);
-
+    wxFileName::SplitPath(txtFilename->GetValue(), NULL, NULL, &FilenameOnly, NULL);
+    wxFileDialog file(this, title, ::wxPathOnly(txtFilename->GetValue()), FilenameOnly, prompt, wxFD_SAVE);
+    
     if (file.ShowModal() == wxID_OK)
     {
         txtFilename->SetValue(file.GetPath());
@@ -136,9 +137,10 @@ wxString frmBackupServer::getCmdPart1()
     else
         cmd=pgBackupAllExecutable;
 
-    cmd +=  wxT(" -i")
-            wxT(" -h ") + server->GetName()
-         +  wxT(" -p ") + NumToStr((long)server->GetPort())
+    if (!server->GetName().IsEmpty())
+        cmd += wxT(" -h ") + server->GetName();
+
+    cmd +=  wxT(" -p ") + NumToStr((long)server->GetPort())
          +  wxT(" -U ") + server->GetUsername();
     return cmd;
 }
