@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmConfig.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmConfig.cpp 7250 2008-05-01 20:21:42Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -225,7 +225,7 @@ void frmConfig::OnClose(wxCloseEvent& event)
 
 void frmConfig::OnHelp(wxCommandEvent& event)
 {
-	DisplayHelp(GetHelpPage(), HELP_PGADMIN);
+	DisplayHelp(GetHelpPage(), HELP_POSTGRESQL);
 }
 
 void frmConfig::OnHint(wxCommandEvent& event)
