@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmEditGrid.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmEditGrid.cpp 7273 2008-05-03 20:21:18Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -340,7 +340,6 @@ void frmEditGrid::SetSortCols(const wxString &cols)
 { 
 	if (orderBy != cols) { 
 		orderBy = cols; 
-		optionsChanged = true;
 	} 
 }
 
@@ -348,7 +347,6 @@ void frmEditGrid::SetFilter(const wxString &filter)
 { 
 	if (rowFilter != filter) { 
 		rowFilter = filter; 
-		optionsChanged = true;
 	} 
 }
 
@@ -402,7 +400,7 @@ void frmEditGrid::OnCellChange(wxGridEvent& event)
                 doSkip = DoSave();
             }
         }
-        else if (sqlGrid->GetGridCursorRow() != event.GetRow() || table->IsLineSaved(sqlGrid->GetGridCursorRow()))
+        else if (sqlGrid->GetGridCursorRow() != event.GetRow())
         {
             toolBar->EnableTool(MNU_SAVE, false);
             toolBar->EnableTool(MNU_UNDO, false);
@@ -500,8 +498,7 @@ void frmEditGrid::OnPaste(wxCommandEvent &ev)
                     break;
 
                 case wxID_NO:
-                    sqlGrid->GetTable()->UndoLine(sqlGrid->GetGridCursorRow());
-                    sqlGrid->ForceRefresh();
+                    CancelChange();
                     break;
             }
         }
@@ -737,13 +734,46 @@ bool frmEditGrid::DoSave()
     return true;
 }
 
+void frmEditGrid::CancelChange()
+{
+    sqlGrid->HideCellEditControl();
+    sqlGrid->SaveEditControlValue();
+    sqlGrid->DisableCellEditControl();
+
+    toolBar->EnableTool(MNU_SAVE, false);
+    toolBar->EnableTool(MNU_UNDO, false);
+    fileMenu->Enable(MNU_SAVE, false);
+    editMenu->Enable(MNU_UNDO, false);
+
+    sqlGrid->GetTable()->UndoLine(sqlGrid->GetGridCursorRow());
+    sqlGrid->ForceRefresh();  
+}
+
 void frmEditGrid::OnOptions(wxCommandEvent& event)
 {
-	optionsChanged = false;
-    dlgEditGridOptions *winOptions = new dlgEditGridOptions(this, connection, tableName, sqlGrid);
-    winOptions->ShowModal();
+    if (toolBar->GetToolEnabled(MNU_SAVE))
+    {
+        wxMessageDialog msg(this, _("There is unsaved data in a row.\nDo you want to store to the database?"), _("Unsaved data"),
+            wxYES_NO | wxICON_QUESTION | wxCANCEL);
+        switch (msg.ShowModal())
+        {
+            case wxID_YES:
+            {
+                if (!DoSave())
+                    return;
+                break;
+            }
+            case wxID_CANCEL:
+                return;
+            case wxID_NO:
+                CancelChange();
+        }
+    }
 
-	if (optionsChanged) Go();
+    dlgEditGridOptions *winOptions = new dlgEditGridOptions(this, connection, tableName, sqlGrid);
+    
+	if (winOptions->ShowModal())
+	    Go();
 }
 
 template < class T >
