@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmGrantWizard.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmGrantWizard.cpp 7321 2008-05-29 15:16:28Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -253,9 +253,18 @@ wxString frmGrantWizard::GetSql()
             {
                 case PGM_FUNCTION:
                 {
-                    tmp = securityPage->GetGrant(wxT("X"), wxT("FUNCTION ") 
-                        + obj->GetQuotedFullIdentifier() + wxT("(")
-                        + ((pgFunction*)obj)->GetArgSigList() + wxT(")"));
+					if (((pgFunction*)obj)->GetIsProcedure())
+					{
+						tmp = securityPage->GetGrant(wxT("X"), wxT("PROCEDURE ") 
+							+ obj->GetQuotedFullIdentifier() + wxT("(")
+							+ ((pgProcedure*)obj)->GetArgSigList() + wxT(")"));
+					}
+					else
+					{
+						tmp = securityPage->GetGrant(wxT("X"), wxT("FUNCTION ") 
+							+ obj->GetQuotedFullIdentifier() + wxT("(")
+							+ ((pgFunction*)obj)->GetArgSigList() + wxT(")"));
+					}
                     break;
                 }
                 case PGM_VIEW:
