@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmHbaConfig.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmHbaConfig.cpp 7250 2008-05-01 20:21:42Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -223,7 +223,7 @@ wxString frmHbaConfig::GetHintString()
 
 wxString frmHbaConfig::GetHelpPage() const
 {
-    wxString page= wxT("pg/client-authentication");
+    wxString page= wxT("client-authentication");
 ;
     return page;
 }
