@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmHint.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmHint.cpp 7034 2008-02-01 13:31:41Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -24,6 +24,7 @@
 #include "frm/frmHint.h"
 #include "frm/frmMain.h"
 #include "schema/pgObject.h"
+#include "utils/misc.h"
 #include "utils/utffile.h"
 
 // Icons
@@ -222,7 +223,7 @@ void frmHint::SetHint(const wxString &info)
         SetTitle(_("Guru Hint") + wxString(wxT(" - ")) + wxGetTranslation(hintArray[currentHint].hintCaption));
 
         wxString page=GetPage(hintArray[currentHint].hintPage);
-        page.Replace(wxT("<INFO>"), info);
+        page.Replace(wxT("<INFO>"), HtmlEntities(info));
 
         htmlHint->SetPage(page);
     }
