@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmMain.cpp 6936 2008-01-02 13:57:28Z dpage $
+// RCS-ID:      $Id: frmMain.cpp 7253 2008-05-02 09:00:25Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -482,6 +482,11 @@ void frmMain::Refresh(pgObject *data)
 
             newData->SetId(currentItem);    // not done automatically
             browser->SetItemData(currentItem, newData);
+
+			// Update the node text if this is an object, as it may have been renamed
+			if (!newData->IsCollection())
+				browser->SetItemText(currentItem, newData->GetDisplayName());
+
             delete data;
         }
         else
