@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmMainConfig.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmMainConfig.cpp 7250 2008-05-01 20:21:42Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -227,7 +227,7 @@ wxString frmMainConfig::GetHelpPage() const
 {
     wxString page;
     if (page.IsEmpty())
-    	page=wxT("pg/runtime-config");
+    	page=wxT("runtime-config");
 
     return page;
 }
