@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmPgpassConfig.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmPgpassConfig.cpp 7250 2008-05-01 20:21:42Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -197,7 +197,7 @@ wxString frmPgpassConfig::GetHintString()
 
 wxString frmPgpassConfig::GetHelpPage() const
 {
-    wxString page= wxT("pg/libpq-pgpass");
+    wxString page= wxT("libpq-pgpass");
 ;
     return page;
 }
