@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmQuery.cpp 7258 2008-05-02 09:25:23Z dpage $
+// RCS-ID:      $Id: frmQuery.cpp 7353 2008-06-04 08:07:22Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -1737,7 +1737,7 @@ void frmQuery::OnQueryComplete(wxCommandEvent &ev)
         {
             pgError err = sqlResult->GetResultError();
             wxString errMsg = err.formatted_msg;
-            wxLogQuietError(conn->GetLastError().Trim().c_str());
+            wxLogQuietError(wxT("%s"), conn->GetLastError().Trim().c_str());
 
             long errPos;
             err.statement_pos.ToLong(&errPos);
