@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmRestore.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmRestore.cpp 7243 2008-04-29 09:06:34Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -132,7 +132,11 @@ wxString frmRestore::GetHelpPage() const
 
 void frmRestore::OnSelectFilename(wxCommandEvent &ev)
 {
-    wxFileDialog file(this, _("Select backup filename"), ::wxPathOnly(txtFilename->GetValue()), txtFilename->GetValue(), 
+    
+    wxString FilenameOnly;    
+    wxFileName::SplitPath(txtFilename->GetValue(), NULL, NULL, &FilenameOnly, NULL);
+    
+    wxFileDialog file(this, _("Select backup filename"), ::wxPathOnly(txtFilename->GetValue()), FilenameOnly, 
         _("Backup files (*.backup)|*.backup|All files (*.*)|*.*"));
 
     if (file.ShowModal() == wxID_OK)
@@ -276,11 +280,12 @@ wxString frmRestore::getCmdPart1()
     else
         cmd=pgRestoreExecutable;
 
-    cmd += wxT(" -i")
-           wxT(" -h ") + server->GetName()
-         + wxT(" -p ") + NumToStr((long)server->GetPort())
+    if (!server->GetName().IsEmpty())
+        cmd += wxT(" -h ") + server->GetName();
+
+    cmd += wxT(" -p ") + NumToStr((long)server->GetPort())
          + wxT(" -U ") + qtIdent(server->GetUsername())
-         + wxT(" -d ") + qtIdent(object->GetDatabase()->GetName());
+         + wxT(" -d ") + commandLineCleanOption(object->GetDatabase()->GetQuotedIdentifier());
     return cmd;
 }
 
