@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmStatus.cpp 6687 2007-09-28 12:42:20Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: frmStatus.cpp 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // frmStatus.cpp - Status Screen
@@ -126,10 +126,12 @@ frmStatus::frmStatus(frmMain *form, const wxString& _title, pgConn *conn)
 
     statusList->AddColumn(_("Query"), 500);
 
-    lockList->AddColumn(wxT("PID"), 50);
+    lockList->AddColumn(wxT("PID"), 35);
     lockList->AddColumn(_("Database"), 50);
     lockList->AddColumn(_("Relation"), 50);
     lockList->AddColumn(_("User"), 50);
+    if (connection->BackendMinimumVersion(8, 3))
+        lockList->AddColumn(_("XID"), 50);
     lockList->AddColumn(_("TX"), 50);
     lockList->AddColumn(_("Mode"), 50);
     lockList->AddColumn(_("Granted"), 50);
@@ -211,8 +213,11 @@ frmStatus::frmStatus(frmMain *form, const wxString& _title, pgConn *conn)
 	btnTerminateSt->Enable(false);
 	btnCancelLk->Enable(false);
 	btnTerminateLk->Enable(false);
-	btnCommit->Enable(false);
-	btnRollback->Enable(false);
+    if (connection->BackendMinimumVersion(8, 1))
+    {
+	    btnCommit->Enable(false);
+	    btnRollback->Enable(false);
+    }
 
 	loaded = true;
 }
@@ -274,8 +279,11 @@ void frmStatus::OnNotebookPageChanged(wxNotebookEvent& event)
 	btnTerminateSt->Enable(false);
 	btnCancelLk->Enable(false);
 	btnTerminateLk->Enable(false);
-	btnCommit->Enable(false);
-	btnRollback->Enable(false);
+    if (connection->BackendMinimumVersion(8, 1))
+    {
+    	btnCommit->Enable(false);
+	    btnRollback->Enable(false);
+    }
 }
 
 
@@ -417,7 +425,21 @@ void frmStatus::OnRefresh(wxCommandEvent &event)
 		// Locks
 		long row=0;
 		wxString sql;
-		if (connection->BackendMinimumVersion(7, 4)) {
+		if (connection->BackendMinimumVersion(8, 3)) 
+        {
+            sql = wxT("SELECT ")
+                  wxT("(SELECT datname FROM pg_database WHERE oid = pgl.database) AS dbname, ")
+                  wxT("pgl.relation::regclass AS class, ")
+                  wxT("pg_get_userbyid(pg_stat_get_backend_userid(svrid)) as user, ")
+                  wxT("pgl.virtualxid, pgl.virtualtransaction AS transaction, pg_stat_get_backend_pid(svrid) AS pid, pgl.mode, pgl.granted, ")
+                  wxT("pg_stat_get_backend_activity(svrid) AS current_query, ")
+                  wxT("pg_stat_get_backend_activity_start(svrid) AS query_start ")
+                  wxT("FROM pg_stat_get_backend_idset() svrid, pg_locks pgl ")
+                  wxT("WHERE pgl.pid = pg_stat_get_backend_pid(svrid) ")
+                  wxT("ORDER BY pid;");
+		} 
+        else if (connection->BackendMinimumVersion(7, 4)) 
+        {
             sql = wxT("SELECT ")
                   wxT("(SELECT datname FROM pg_database WHERE oid = pgl.database) AS dbname, ")
                   wxT("pgl.relation::regclass AS class, ")
@@ -428,7 +450,9 @@ void frmStatus::OnRefresh(wxCommandEvent &event)
                   wxT("FROM pg_stat_get_backend_idset() svrid, pg_locks pgl ")
                   wxT("WHERE pgl.pid = pg_stat_get_backend_pid(svrid) ")
                   wxT("ORDER BY pid;");
-		} else {
+		} 
+        else 
+        {
             sql = wxT("SELECT ")
                   wxT("(SELECT datname FROM pg_database WHERE oid = pgl.database) AS dbname, ")
                   wxT("pgl.relation::regclass AS class, ")
@@ -472,6 +496,8 @@ void frmStatus::OnRefresh(wxCommandEvent &event)
 					lockList->SetItem(row, colpos++, dataSet2->GetVal(wxT("dbname")));
 					lockList->SetItem(row, colpos++, dataSet2->GetVal(wxT("class")));
 					lockList->SetItem(row, colpos++, dataSet2->GetVal(wxT("user")));
+		            if (connection->BackendMinimumVersion(8, 3)) 
+                        lockList->SetItem(row, colpos++, dataSet2->GetVal(wxT("virtualxid")));
 					lockList->SetItem(row, colpos++, dataSet2->GetVal(wxT("transaction")));
 					lockList->SetItem(row, colpos++, dataSet2->GetVal(wxT("mode")));
 					
