@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgConn.h 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgConn.h 7215 2008-04-04 12:28:00Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -125,7 +125,7 @@ public:
     void RegisterNoticeProcessor(PQnoticeProcessor proc, void *arg);
     wxMBConv *GetConv() { return conv; };
 
-    void LogError();
+    void LogError(const bool quiet=false);
 
     bool IsSSLconnected();
     PGconn *connection() { return conn; }
@@ -155,6 +155,8 @@ protected:
     friend class pgQueryThread;
 
 private:
+    wxString qtString(const wxString& value);
+    
     bool features[32];
     int minorVersion, majorVersion;
     bool isEdb;
