@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmEditGrid.h 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: frmEditGrid.h 7264 2008-05-02 10:30:45Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -21,7 +21,7 @@
 #include "dlg/dlgClasses.h"
 #include "ctl/ctlSQLGrid.h"
 
-#define FRMEDITGRID_PERPSECTIVE_VER wxT("$Rev: 6930 $")
+#define FRMEDITGRID_PERPSECTIVE_VER wxT("$Rev: 7264 $")
 
 #ifdef __WXMAC__
 #define FRMEDITGRID_DEFAULT_PERSPECTIVE wxT("layout2|name=toolBar;caption=Tool bar;state=16788208;dir=1;layer=10;row=0;pos=0;prop=100000;bestw=240;besth=23;minw=-1;minh=-1;maxw=-1;maxh=-1;floatx=-1;floaty=-1;floatw=-1;floath=-1|name=limitBar;caption=Limit bar;state=16788208;dir=1;layer=10;row=0;pos=243;prop=100000;bestw=120;besth=21;minw=-1;minh=-1;maxw=-1;maxh=-1;floatx=415;floaty=793;floatw=-1;floath=-1|name=sqlGrid;caption=Data grid;state=1020;dir=5;layer=0;row=0;pos=0;prop=100000;bestw=300;besth=200;minw=200;minh=100;maxw=-1;maxh=-1;floatx=-1;floaty=-1;floatw=-1;floath=-1|name=scratchPad;caption=Scratch pad;state=16779260;dir=3;layer=0;row=0;pos=0;prop=100000;bestw=300;besth=150;minw=200;minh=100;maxw=-1;maxh=-1;floatx=347;floaty=725;floatw=-1;floath=-1|dock_size(1,10,0)=25|dock_size(5,0,0)=84|dock_size(3,0,0)=173|")
@@ -207,6 +207,7 @@ private:
     void OnOptions(wxCommandEvent& event);
     void OnSave(wxCommandEvent& event);
     bool DoSave();
+	void CancelChange();
     void OnUndo(wxCommandEvent& event);
     void OnCellChange(wxGridEvent& event);
     void OnGridSelectCells(wxGridRangeSelectEvent& event);
@@ -238,7 +239,6 @@ private:
     char relkind;
     OID relid;
     bool hasOids;
-	bool optionsChanged;
     wxString tableName;
     wxString primaryKeyColNumbers;
     wxString orderBy;
@@ -286,3 +286,4 @@ public:
 
 #endif
 
+
