@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: edbPackage.h 6082 2007-03-16 12:58:18Z dpage $
-// Copyright (C) 2002 - 2007, The pgAdmin Development Team
+// RCS-ID:      $Id: edbPackage.h 6930 2008-01-02 00:10:01Z dpage $
+// Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // edbPackage.h - EnterpriseDB Package class
@@ -56,6 +56,7 @@ public:
 
     bool IsUpToDate();
 
+    wxString GetHelpPage(bool forCreate) const { return wxT("pg/packages-create"); }
 private:
     wxString GetInner(const wxString &def);
 
@@ -99,6 +100,8 @@ public:
     : pgSchemaObjCollection(factory, _package->GetSchema()) { iSetOid(_package->GetOid()); package=_package; }
     virtual edbPackage *GetPackage() const { return package; }
 
+    virtual bool CanCreate() { return false; }
+
 protected:
     edbPackage *package;
 };
