@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgColumn.h 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgColumn.h 7087 2008-02-24 10:45:47Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -75,6 +75,8 @@ public:
     void iSetStorage(const wxString& s) { storage=s; }
     long GetInheritedCount() const { return inheritedCount; }
     void iSetInheritedCount(const long l) { inheritedCount=l; }
+    bool GetIsLocal() const { return isLocal; }
+    void iSetIsLocal(const bool b) { isLocal=b; }
     OID  GetAttTypId() const { return attTypId; }
     void iSetAttTypId(const OID o) { attTypId =o; }
     long GetAttstattarget() const { return attstattarget; }
@@ -105,7 +107,7 @@ private:
     wxString serialSequence, serialSchema, pkCols;
     long colNumber, length, precision, statistics, attstattarget;
     long typlen, typmod, inheritedCount;
-    bool isPK, isFK, notNull, isArray;
+    bool isPK, isFK, notNull, isArray, isLocal;
     OID attTypId;
     int isReferenced;
 };
