@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: sysLogger.h 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: sysLogger.h 7215 2008-04-04 12:28:00Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -41,9 +41,10 @@ private:
 
 #define wxLOG_Notice (wxLOG_User+1)
 #define wxLOG_Sql (wxLOG_User+2)
+#define wxLOG_QuietError (wxLOG_User+3)
 
 DECLARE_LOG_FUNCTION(Notice);
 DECLARE_LOG_FUNCTION(Sql);
-
+DECLARE_LOG_FUNCTION(QuietError);
 
 #endif
