@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgAdmin3.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgAdmin3.cpp 7183 2008-03-22 10:27:36Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -247,7 +247,7 @@ bool pgAdmin3::OnInit()
     wxString msg;
     msg << wxT("# ") << appearanceFactory->GetLongAppName() << wxT(" Version ") << VERSION_STR << wxT(" Startup");
     wxLogInfo(wxT("##############################################################"));
-    wxLogInfo(msg);
+    wxLogInfo(wxT("%s"), msg.c_str());
     wxLogInfo(wxT("##############################################################"));
 
 #ifdef SSL
@@ -887,6 +887,43 @@ void pgAdmin3::InitPaths()
         edbBackupAllExecutable = wxEmptyString;
     if (!isEdbApp(edbRestoreExecutable))
         edbRestoreExecutable = wxEmptyString;
+
+    // Now sanitize all the paths
+    wxFileName thePath;
+    if (loadPath.Length())
+    {
+        thePath = wxFileName::DirName(loadPath);
+        thePath.Normalize();
+        loadPath = thePath.GetLongPath();
+    }
+
+    if (docPath.Length())
+    {
+        thePath = wxFileName::DirName(docPath);
+        thePath.Normalize();
+        docPath = thePath.GetLongPath();
+    }
+
+    if (uiPath.Length())
+    {
+        thePath = wxFileName::DirName(uiPath);
+        thePath.Normalize();
+        uiPath = thePath.GetLongPath();
+    }
+
+    if (i18nPath.Length())
+    {
+        thePath = wxFileName::DirName(i18nPath);
+        thePath.Normalize();
+        i18nPath = thePath.GetLongPath();
+    }
+
+    if (brandingPath.Length())
+    {
+        thePath = wxFileName::DirName(brandingPath);
+        thePath.Normalize();
+        brandingPath = thePath.GetLongPath();
+    }
 }
 
 void pgAdmin3::InitHelp()
@@ -1034,7 +1071,7 @@ void pgAdmin3::InitHelp()
     if (pgHelpPath.IsEmpty())
         pgHelpPath = wxT("http://www.postgresql.org/docs/current/static/");
     if (edbHelpPath.IsEmpty())
-        edbHelpPath = wxT("http://www.enterprisedb.com/documentation/8.2/");
+        edbHelpPath = wxT("http://www.enterprisedb.com/docs/en/8.3/server/");
     if (slonyHelpPath.IsEmpty())
         slonyHelpPath = wxT("http://www.slony.info/documentation/");
 
