@@ -199,7 +199,7 @@ edbPackageFunction *edbPackageFunctionFactory::AppendFunctions(pgObject *obj, ed
     packageFunctions = obj->GetDatabase()->ExecuteSet(sql);
 
     pgSet *types = obj->GetDatabase()->ExecuteSet(wxT(
-                    "SELECT oid, format_type(oid, typtypmod) AS typname FROM pg_type"));
+                    "SELECT oid, format_type(oid, NULL) AS typname FROM pg_type"));
 
     typeMap map;
 
