@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatabase.cpp 7026 2008-01-31 13:53:02Z dpage $
+// RCS-ID:      $Id: pgDatabase.cpp 7038 2008-02-01 22:09:23Z guillaume $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -482,9 +482,9 @@ pgObject *pgDatabaseFactory::CreateObjects(pgCollection *collection, ctlTree *br
     if (!collection->GetServer()->GetDbRestriction().IsEmpty())
     {
         if (restr.IsEmpty())
-            restr = wxT(" WHERE (");
+            restr = wxT(" WHERE datname NOT IN (");
         else
-            restr = wxT("   AND (");
+            restr = wxT("   AND datname NOT IN (");
 
         restr += collection->GetServer()->GetDbRestriction() + wxT(")\n");
     }
