@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatatype.cpp 6982 2008-01-08 15:19:03Z dpage $
+// RCS-ID:      $Id: pgDatatype.cpp 7074 2008-02-13 15:51:58Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -164,7 +164,7 @@ DatatypeReader::DatatypeReader(pgDatabase *db, bool withDomains)
     else
         condition += wxT("IN ('b', 'c', 'e')");
 
-    condition += wxT("AND typname NOT IN (SELECT relname FROM pg_class WHERE relnamespace = typnamespace AND relkind != 'c') ");
+    condition += wxT("AND typname NOT IN (SELECT relname FROM pg_class WHERE relnamespace = typnamespace AND relkind != 'c' UNION SELECT '_' || relname FROM pg_class WHERE relnamespace = typnamespace AND relkind != 'c') ");
 
     if (!settings->GetShowSystemObjects())
         condition += wxT(" AND nsp.nspname NOT LIKE 'information_schema'");
