@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgFunction.cpp 6984 2008-01-08 16:53:15Z dpage $
+// RCS-ID:      $Id: pgFunction.cpp 7205 2008-03-27 19:13:25Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -347,7 +347,7 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
             wxT(" ORDER BY proname"));
 
     pgSet *types = obj->GetDatabase()->ExecuteSet(wxT(
-                    "SELECT oid, format_type(oid, typtypmod) AS typname FROM pg_type"));
+                    "SELECT oid, format_type(oid, NULL) AS typname FROM pg_type"));
 
     typeMap map;
 
@@ -382,7 +382,8 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
 
             
             // Tokenize the arguments
-            wxStringTokenizer argNamesTkz(wxEmptyString), argTypesTkz(wxEmptyString), argModesTkz(wxEmptyString);
+            wxStringTokenizer argTypesTkz(wxEmptyString), argModesTkz(wxEmptyString);
+            queryTokenizer argNamesTkz(wxEmptyString, (wxChar)',');
             wxString tmp;
 
             // We always have types
