@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgIndex.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgIndex.cpp 7089 2008-02-24 11:10:12Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -312,7 +312,7 @@ bool pgIndexBase::HasPgstatindex()
 
 executePgstatindexFactory::executePgstatindexFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar) : contextActionFactory(list)
 {
-    mnu->Append(id, _("&Extended statistics"), _("Get extended statistics via pgstatindex for the selected object."), wxITEM_CHECK);
+    mnu->Append(id, _("&Extended index statistics"), _("Get extended statistics via pgstatindex for the selected object."), wxITEM_CHECK);
 }
 
 
