@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSchema.cpp 6936 2008-01-02 13:57:28Z dpage $
+// RCS-ID:      $Id: pgSchema.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -265,7 +265,7 @@ pgObject *pgSchemaBaseFactory::CreateObjects(pgCollection *collection, ctlTree *
         restr += wxT("  AND nsp.nspparent = 0\n");
 
     if (!collection->GetDatabase()->GetSchemaRestriction().IsEmpty())
-        restr += wxT("  AND (") + collection->GetDatabase()->GetSchemaRestriction() + wxT(")");
+        restr += wxT("  AND nspname NOT IN (") + collection->GetDatabase()->GetSchemaRestriction() + wxT(")");
 
 	wxString sql;
 
@@ -283,12 +283,12 @@ pgObject *pgSchemaBaseFactory::CreateObjects(pgCollection *collection, ctlTree *
 	{
 		if (collection->GetDatabase()->BackendMinimumVersion(8, 1))
 		{
-			sql = wxT("SELECT CASE WHEN nspname LIKE E'pg\\\\_temp\\\\_%%' THEN 1\n")
+			sql = wxT("SELECT CASE WHEN nspname LIKE E'pg\\\\_temp\\\\_%' THEN 1\n")
 			      wxT("            WHEN (nspname LIKE E'pg\\\\_%') THEN 0\n");
 		}
 		else
 		{
-			sql = wxT("SELECT CASE WHEN nspname LIKE 'pg\\\\_temp\\\\_%%' THEN 1\n")
+			sql = wxT("SELECT CASE WHEN nspname LIKE 'pg\\\\_temp\\\\_%' THEN 1\n")
 				  wxT("            WHEN (nspname LIKE 'pg\\\\_%') THEN 0\n");
 		}
 		sql += wxT("            ELSE 3 END AS nsptyp,\n")
