@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgServer.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgServer.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -337,7 +337,19 @@ bool pgServer::StopService()
                             done=false;
                     }
                     if (done)
+                    {
                         done = (::ControlService(serviceHandle, SERVICE_CONTROL_STOP, &st) != 0);
+
+                        int retries = 10;
+                        while (!done && retries > 0)
+                        {
+                            done = (::ControlService(serviceHandle, SERVICE_CONTROL_STOP, &st) != 0);
+                            retries--;
+
+                            wxSleep(5);
+                        }
+
+                    }
                 }
             }
             // report error
@@ -799,7 +811,7 @@ void pgServer::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prop
             expandedKids=true;
             // Log
             
-            wxLogInfo(wxT("Adding child object to server ") + GetIdentifier());
+            wxLogInfo(wxT("Adding child object to server %s"), GetIdentifier().c_str());
     
             if (settings->GetDisplayOption(_("Databases")))
                 browser->AppendCollection(this, databaseFactory);
@@ -937,7 +949,7 @@ void pgServer::ShowStatistics(frmMain *form, ctlListView *statistics)
 {
     if (conn)
     {
-        wxLogInfo(wxT("Displaying statistics for server ") + GetIdentifier());
+        wxLogInfo(wxT("Displaying statistics for server %s"), GetIdentifier().c_str());
 
         // Add the statistics view columns
         statistics->ClearAll();
