@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTable.cpp 6936 2008-01-02 13:57:28Z dpage $
+// RCS-ID:      $Id: pgTable.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -171,22 +171,45 @@ wxString pgTable::GetSql(ctlTree *browser)
             + wxT("-- DROP TABLE ") + GetQuotedFullIdentifier() + wxT(";")
             + wxT("\n\nCREATE TABLE ") + GetQuotedFullIdentifier() + wxT("\n(\n");
 
+        // Get a count of the constraints.
+        int consCount=0;
+        pgCollection *constraints=browser->FindCollection(primaryKeyFactory, GetId());
+        if (constraints)
+            consCount = browser->GetChildrenCount(constraints->GetId());
+
+        // Get the columns
         pgCollection *columns=browser->FindCollection(columnFactory, GetId());
         if (columns)
         {
             columns->ShowTreeDetail(browser);
-            treeObjectIterator colIt(browser, columns);
+            treeObjectIterator colIt1(browser, columns);
+            treeObjectIterator colIt2(browser, columns);
 
-            int colCount=0;
+            int lastRealCol=0;
+            int currentCol=0;
             pgColumn *column;
-            while ((column = (pgColumn*)colIt.GetNextObject()) != 0)
+
+            // Iterate the columns to find the last 'real' one
+            while ((column = (pgColumn*)colIt1.GetNextObject()) != 0)
+             {
+                currentCol++;
+
+                if (column->GetInheritedCount() == 0)
+                    lastRealCol = currentCol;
+            }
+
+            // Now build the actual column list
+            int colCount=0;
+            while ((column = (pgColumn*)colIt2.GetNextObject()) != 0)
             {
                 column->ShowTreeDetail(browser);
                 if (column->GetColNumber() > 0)
                 {
                     if (colCount)
                     {
-                        sql += wxT(",");
+                        // Only add a comma if this isn't the last 'real' column, or if there are constraints
+                        if (colCount != lastRealCol || consCount)
+                            sql += wxT(",");
                         if (!prevComment.IsEmpty())
                             sql += wxT(" -- ") + firstLineOnly(prevComment);
 
@@ -194,7 +217,10 @@ wxString pgTable::GetSql(ctlTree *browser)
                     }
 
                     if (column->GetInheritedCount() > 0)
-                        sql += wxString::Format(wxT("-- %s: "), _("Inherited"));
+					{
+					    if (!column->GetIsLocal())
+							sql += wxString::Format(wxT("-- %s: "), _("Inherited"));
+					}
 
                     sql += wxT("  ") + column->GetQuotedIdentifier() + wxT(" ")
                         + column->GetDefinition();
@@ -212,7 +238,7 @@ wxString pgTable::GetSql(ctlTree *browser)
             }
         }
 
-        pgCollection *constraints=browser->FindCollection(primaryKeyFactory, GetId());
+        // Now iterate the constraints
         if (constraints)
         {
             constraints->ShowTreeDetail(browser);
@@ -714,7 +740,7 @@ pgTableCollection::pgTableCollection(pgaFactory *factory, pgSchema *sch)
     
 void pgTableCollection::ShowStatistics(frmMain *form, ctlListView *statistics)
 {
-    wxLogInfo(wxT("Displaying statistics for tables on ")+ GetSchema()->GetIdentifier());
+    wxLogInfo(wxT("Displaying statistics for tables on %s"), GetSchema()->GetIdentifier().c_str());
 
     bool hasSize=GetConnection()->HasFeature(FEATURE_SIZE);
 
@@ -976,7 +1002,7 @@ bool countRowsFactory::CheckEnable(pgObject *obj)
 
 executePgstattupleFactory::executePgstattupleFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar) : contextActionFactory(list)
 {
-    mnu->Append(id, _("&Extended statistics"), _("Get extended statistics via pgstattuple for the selected object."), wxITEM_CHECK);
+    mnu->Append(id, _("&Extended table statistics"), _("Get extended statistics via pgstattuple for the selected object."), wxITEM_CHECK);
 }
 
 
@@ -1062,3 +1088,4 @@ bool enableAllTriggersFactory::CheckEnable(pgObject *obj)
                && ((pgTable*)obj)->GetConnection()->BackendMinimumVersion(8, 1);
 }
 
+
