@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTrigger.cpp 7012 2008-01-23 14:04:46Z dpage $
+// RCS-ID:      $Id: pgTrigger.cpp 7212 2008-04-04 09:18:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -202,8 +202,8 @@ pgObject *pgTrigger::Refresh(ctlTree *browser, const wxTreeItemId item)
     pgCollection *coll=browser->GetParentCollection(item);
     if (coll)
     {
-        wxString restr = wxT("\n   AND t.tgname='") + GetName() + 
-                         wxT("' AND cl.oid=") + GetTable()->GetOidStr() + 
+        wxString restr = wxT("\n   AND t.tgname=") + qtDbString(GetName()) + 
+                         wxT(" AND cl.oid=") + GetTable()->GetOidStr() + 
                          wxT("::oid AND cl.relnamespace=") + GetSchema()->GetOidStr() + wxT("::oid");
         trigger = triggerFactory.CreateObjects(coll, 0, restr);
     }
