@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgType.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: pgType.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -222,9 +222,9 @@ pgObject *pgTypeFactory::CreateObjects(pgCollection *collection, ctlTree *browse
 					wxT("  LEFT OUTER JOIN pg_description des ON des.objoid=t.oid\n");
 
 	if (collection->GetDatabase()->BackendMinimumVersion(8, 1))
-		sql += wxT(" WHERE t.typtype != 'd' AND t.typname NOT LIKE E'\\\\_%%' AND t.typnamespace = ") + collection->GetSchema()->GetOidStr() + wxT("\n");
+		sql += wxT(" WHERE t.typtype != 'd' AND t.typname NOT LIKE E'\\\\_%' AND t.typnamespace = ") + collection->GetSchema()->GetOidStr() + wxT("\n");
 	else
-		sql += wxT(" WHERE t.typtype != 'd' AND t.typname NOT LIKE '\\\\_%%' AND t.typnamespace = ") + collection->GetSchema()->GetOidStr() + wxT("\n");
+		sql += wxT(" WHERE t.typtype != 'd' AND t.typname NOT LIKE '\\\\_%' AND t.typnamespace = ") + collection->GetSchema()->GetOidStr() + wxT("\n");
 
 	sql += restriction + systemRestriction +
 			wxT(" ORDER BY t.typname");
