@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgView.cpp 6999 2008-01-16 15:31:52Z dpage $
+// RCS-ID:      $Id: pgView.cpp 7270 2008-05-03 20:03:41Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -69,10 +69,15 @@ wxString pgView::GetSql(ctlTree *browser)
             + wxT("\n\nCREATE OR REPLACE VIEW ") + GetQuotedFullIdentifier() + wxT(" AS \n")
             + GetFormattedDefinition()
             + wxT("\n\n") 
-            + GetOwnerSql(7, 3, wxT("TABLE ") + GetQuotedFullIdentifier())
-            + GetGrant(wxT("arwdRxt"), wxT("TABLE ") + GetQuotedFullIdentifier())
-            + GetCommentSql()
-            + wxT("\n");
+            + GetOwnerSql(7, 3, wxT("TABLE ") + GetQuotedFullIdentifier());
+
+        if (GetConnection()->BackendMinimumVersion(8, 2))
+            sql += GetGrant(wxT("arwdxt"), wxT("TABLE ") + GetQuotedFullIdentifier());
+        else
+            sql += GetGrant(wxT("arwdRxt"), wxT("TABLE ") + GetQuotedFullIdentifier());
+
+        sql += GetCommentSql()
+             + wxT("\n");
 
         pgCollection *columns=browser->FindCollection(columnFactory, GetId());
         if (columns)
