@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: slCluster.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: slCluster.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -271,7 +271,7 @@ void slCluster::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *pro
             delete set;
         }
 
-        wxLogInfo(wxT("Adding child object to cluster ") + GetIdentifier());
+        wxLogInfo(wxT("Adding child object to cluster %s"), GetIdentifier().c_str());
 
         browser->AppendCollection(this, nodeFactory);
         browser->AppendCollection(this, setFactory);
