@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: slSet.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: slSet.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -172,7 +172,7 @@ void slSet::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *propert
 
         browser->RemoveDummyChild(this);
         // Log
-        wxLogInfo(wxT("Adding child object to set ") + GetIdentifier());
+        wxLogInfo(wxT("Adding child object to set %s"), GetIdentifier().c_str());
 
         if (GetOriginId() == GetCluster()->GetLocalNodeID())
         {
@@ -467,3 +467,4 @@ bool slonyMoveSetFactory::CheckEnable(pgObject *obj)
     return set->GetOriginId() == set->GetCluster()->GetLocalNodeID()  && !set->GetLockXXID().IsEmpty();
 }
 
+
