@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: slSubscription.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: slSubscription.cpp 7209 2008-03-31 15:43:56Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -100,7 +100,7 @@ void slSubscription::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView
                 slSet *set=(slSet*)browser->GetObject(id);
                 if (set && set->IsCreatedBy(setFactory))
                 {
-                    wxLogInfo(wxT("Adding child object to subscription ") + GetIdentifier());
+                    wxLogInfo(wxT("Adding child object to subscription %s"), GetIdentifier().c_str());
 
                     browser->AppendCollection(this, slSequenceFactory);
                     browser->AppendCollection(this, slTableFactory);
