@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: misc.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: misc.cpp 7192 2008-03-22 15:34:50Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -370,6 +370,7 @@ static bool needsQuoting(wxString& value, bool forTypes)
                 case REAL:
                 case SET:
                 case SMALLINT:
+				case TEXT_P:
                 case TIME:
                 case TIMESTAMP:
                 case TRIGGER:
@@ -1070,6 +1071,7 @@ wxString firstLineOnly(const wxString &str)
 bool pgAppMinimumVersion(const wxString &cmd, const int majorVer, const int minorVer)
 {
 	wxArrayString output;
+    bool isEnterpriseDB = false;
 
 #ifdef __WXMSW__
  	if (wxExecute(cmd + wxT(" --version"), output, 0) != 0)
@@ -1081,6 +1083,10 @@ bool pgAppMinimumVersion(const wxString &cmd, const int majorVer, const int mino
         return false;
     }
 
+    // Is this an EDB utility?
+    if (output[0].Contains(wxT("EnterpriseDB")))
+        isEnterpriseDB = true;
+
 	wxString version = output[0].AfterLast(' ');
 	long actualMajor = 0, actualMinor = 0;
 	
@@ -1105,6 +1111,11 @@ bool pgAppMinimumVersion(const wxString &cmd, const int majorVer, const int mino
 
     tmp.ToLong(&actualMinor);
 
+    // EnterpriseDB's 8.3R1 utilties are based on PG8.2, so correct the version number here. 
+    // This will need more work when 8.3R2 is released :-(
+    if (isEnterpriseDB && actualMajor == 8 && actualMinor == 3)
+        actualMinor = 2;
+
 	if (actualMajor > majorVer)
 		return true;
 
@@ -1159,3 +1170,38 @@ bool isEdbApp(const wxString &app)
 
 	return false;
 }
+
+// Fixup a (quoted) string for use on the command line
+wxString commandLineCleanOption(const wxString &option)
+{
+    wxString tmp;
+    bool wasQuoted = false;
+
+    if (option.StartsWith(wxT("\"")) && option.EndsWith(wxT("\"")))
+    {
+        tmp = option.AfterFirst((wxChar)'"').BeforeLast((wxChar)'"');
+        wasQuoted = true;
+    }
+    else
+        tmp = option;
+
+#ifdef __WXMSW__
+    if (wasQuoted)
+        tmp.Replace(wxT("\"\""), wxT("\"\"\""));
+    else
+    {
+        tmp.Replace(wxT("\""), wxT("\"\""));
+        tmp.Replace(wxT("\\"), wxT("\\\\"));
+    }
+#else
+    tmp.Replace(wxT("\\"), wxT("\\\\"));
+    tmp.Replace(wxT("\"\""), wxT("\\\""));
+#endif
+
+    if (wasQuoted)
+        tmp = wxT("\"") + tmp + wxT("\"");
+
+    return tmp;
+}
+
+
