@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: sysLogger.cpp 6930 2008-01-02 00:10:01Z dpage $
+// RCS-ID:      $Id: sysLogger.cpp 7215 2008-04-04 12:28:00Z dpage $
 // Copyright (C) 2002 - 2008, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -25,6 +25,27 @@ wxLogLevel sysLogger::logLevel=LOG_ERRORS;
 wxString sysLogger::logFile=wxT("debug.log");
 
 // IMPLEMENT_LOG_FUNCTION(Sql) from wx../common/log.c
+void wxVLogQuietError(const wxChar *szFormat, va_list argptr)
+{
+    static wxChar s_szBuf[1024];
+
+    if (sysLogger::logLevel >= LOG_ERRORS)
+    {
+        wxVsnprintf(s_szBuf, WXSIZEOF(s_szBuf), szFormat, argptr);
+        wxLog::OnLog(wxLOG_QuietError, s_szBuf, time(NULL));
+
+    }
+}
+
+void wxLogQuietError(const wxChar *szFormat, ...)
+{
+    va_list argptr;
+    va_start(argptr, szFormat);
+    wxVLogQuietError(szFormat, argptr);
+    va_end(argptr);
+}
+
+
 void wxVLogSql(const wxChar *szFormat, va_list argptr)
 {
     static wxChar s_szBuf[1024];
@@ -54,8 +75,7 @@ void wxVLogNotice(const wxChar *szFormat, va_list argptr)
     if (sysLogger::logLevel >= LOG_NOTICE)
     {
         wxVsnprintf(s_szBuf, WXSIZEOF(s_szBuf), szFormat, argptr);
-        wxLog::OnLog(wxLOG_Sql, s_szBuf, time(NULL));
-
+        wxLog::OnLog(wxLOG_Notice, s_szBuf, time(NULL));
     }
 }
 
@@ -85,6 +105,10 @@ void sysLogger::DoLog(wxLogLevel level, const wxChar *msg, time_t timestamp)
             icon = wxICON_ERROR;
             break;
 
+        case wxLOG_QuietError:
+            msgtype = wxT("ERROR  ");
+            break;
+
         case wxLOG_Warning:
             msgtype = wxT("WARNING");
             preamble = _("Warning:\n\n");
@@ -146,13 +170,15 @@ void sysLogger::DoLog(wxLogLevel level, const wxChar *msg, time_t timestamp)
 
         case LOG_ERRORS:
             if (level == wxLOG_FatalError || 
-                level == wxLOG_Error)
+                level == wxLOG_Error ||
+                level == wxLOG_QuietError)
                 WriteLog(fullmsg);
             break;
 
         case LOG_NOTICE:
             if (level == wxLOG_FatalError || 
                 level == wxLOG_Error ||
+                level == wxLOG_QuietError ||
                 level == wxLOG_Notice)
                 WriteLog(fullmsg);
             break;
@@ -160,6 +186,7 @@ void sysLogger::DoLog(wxLogLevel level, const wxChar *msg, time_t timestamp)
         case LOG_SQL:
             if (level == wxLOG_FatalError ||
                 level == wxLOG_Error ||
+                level == wxLOG_QuietError ||
                 level == wxLOG_Message ||
                 level == wxLOG_Status ||
                 level == wxLOG_Notice ||
@@ -213,3 +240,4 @@ bool sysLogger::SilenceMessage(const wxString &msg)
     return false;
 }
 
+
