@@ -1,13 +1,17 @@
 /*
 // pgAgent - PostgreSQL Tools
-// $Id: pgagent.sql 4852 2005-12-23 08:30:47Z dpage $
-// Copyright (C) 2003 The pgAdmin Development Team
+// $Id: pgagent.sql 7276 2008-05-06 10:54:54Z dpage $
+// Copyright (C) 2002 - 2006 The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
 // pgagent.sql - pgAgent tables and functions
 //
 */
 
+BEGIN TRANSACTION;
+
+
+
 CREATE SCHEMA pgagent;
 COMMENT ON SCHEMA pgagent IS 'pgAgent system tables';
 
@@ -129,7 +133,7 @@ jslid                serial               NOT NULL PRIMARY KEY,
 jsljlgid             int4                 NOT NULL REFERENCES pgagent.pga_joblog (jlgid) ON DELETE CASCADE ON UPDATE RESTRICT,
 jsljstid             int4                 NOT NULL REFERENCES pgagent.pga_jobstep (jstid) ON DELETE CASCADE ON UPDATE RESTRICT,
 jslstatus            char                 NOT NULL CHECK (jslstatus IN ('r', 's', 'i', 'f', 'd')) DEFAULT 'r', -- running, success, ignored, failed, aborted
-jslresult            int2                 NULL,
+jslresult            int4                 NULL,
 jslstart             timestamptz          NOT NULL DEFAULT current_timestamp,
 jslduration          interval             NULL,
 jsloutput            text
@@ -552,7 +556,7 @@ COMMENT ON FUNCTION pgagent.pga_is_leap_year(int2) IS 'Returns TRUE is $1 is a l
 
 CREATE OR REPLACE FUNCTION pgagent.pga_job_trigger()
   RETURNS "trigger" AS
-$BODY$
+'
 BEGIN
     IF NEW.jobenabled THEN
         IF NEW.jobnextrun IS NULL THEN
@@ -566,7 +570,7 @@ BEGIN
     END IF;
     RETURN NEW;
 END;
-$BODY$
+'
   LANGUAGE 'plpgsql' VOLATILE;
 COMMENT ON FUNCTION pgagent.pga_job_trigger() IS 'Update the job''s next run time.';
 
@@ -631,7 +635,7 @@ BEGIN
     END IF;
 END;
 ' LANGUAGE 'plpgsql' VOLATILE;
-COMMENT ON FUNCTION pgagent.pga_schedule_trigger() IS 'Update the job''s next run time whenever an exception changes';
+COMMENT ON FUNCTION pgagent.pga_exception_trigger() IS 'Update the job''s next run time whenever an exception changes';
 
 
 
@@ -639,3 +643,7 @@ CREATE TRIGGER pga_exception_trigger AFTER INSERT OR UPDATE OR DELETE
   ON pgagent.pga_exception FOR EACH ROW
   EXECUTE PROCEDURE pgagent.pga_exception_trigger();
 COMMENT ON TRIGGER pga_exception_trigger ON pgagent.pga_exception IS 'Update the job''s next run time whenever an exception changes';
+
+
+
+COMMIT TRANSACTION;
